@@ -31,6 +31,8 @@ INSTRUMENT_LIBS = {
     "pika": True,
     "cx_Oracle": True,
     "grpc": True,
+    "ruxit": True,
+    "confluent_kafka": True,
 }
 
 
